==> citrus-http-4.0.2-sources.jar: org/citrusframework/model/config/http/HttpClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.http;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="request-url" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="request-method" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-resolver" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="request-factory" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="rest-template" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="content-type" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="default-accept-header" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="handle-cookies" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="binary-media-types" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="error-handler" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="error-strategy">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             <enumeration value="throwsException"/>
 *             <enumeration value="propagateError"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class HttpClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "request-url")
    protected String requestUrl;
    @XmlAttribute(name = "request-method")
    protected String requestMethod;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "endpoint-resolver")
    protected String endpointResolver;
    @XmlAttribute(name = "request-factory")
    protected String requestFactory;
    @XmlAttribute(name = "rest-template")
    protected String restTemplate;
    @XmlAttribute(name = "charset")
    protected String charset;
    @XmlAttribute(name = "content-type")
    protected String contentType;
    @XmlAttribute(name = "default-accept-header")
    protected Boolean defaultAcceptHeader;
    @XmlAttribute(name = "handle-cookies")
    protected Boolean handleCookies;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "binary-media-types")
    protected String binaryMediaTypes;
    @XmlAttribute(name = "error-handler")
    protected String errorHandler;
    @XmlAttribute(name = "error-strategy")
    protected String errorStrategy;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der requestUrl-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestUrl() {
        return requestUrl;
    }

    /**
     * Legt den Wert der requestUrl-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestUrl(String value) {
        this.requestUrl = value;
    }

    /**
     * Ruft den Wert der requestMethod-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestMethod() {
        return requestMethod;
    }

    /**
     * Legt den Wert der requestMethod-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestMethod(String value) {
        this.requestMethod = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der endpointResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointResolver() {
        return endpointResolver;
    }

    /**
     * Legt den Wert der endpointResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointResolver(String value) {
        this.endpointResolver = value;
    }

    /**
     * Ruft den Wert der requestFactory-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestFactory() {
        return requestFactory;
    }

    /**
     * Legt den Wert der requestFactory-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestFactory(String value) {
        this.requestFactory = value;
    }

    /**
     * Ruft den Wert der restTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRestTemplate() {
        return restTemplate;
    }

    /**
     * Legt den Wert der restTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRestTemplate(String value) {
        this.restTemplate = value;
    }

    /**
     * Ruft den Wert der charset-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCharset() {
        return charset;
    }

    /**
     * Legt den Wert der charset-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCharset(String value) {
        this.charset = value;
    }

    /**
     * Ruft den Wert der contentType-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Legt den Wert der contentType-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContentType(String value) {
        this.contentType = value;
    }

    /**
     * Ruft den Wert der defaultAcceptHeader-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDefaultAcceptHeader() {
        return defaultAcceptHeader;
    }

    /**
     * Legt den Wert der defaultAcceptHeader-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDefaultAcceptHeader(Boolean value) {
        this.defaultAcceptHeader = value;
    }

    /**
     * Ruft den Wert der handleCookies-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isHandleCookies() {
        return handleCookies;
    }

    /**
     * Legt den Wert der handleCookies-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setHandleCookies(Boolean value) {
        this.handleCookies = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der binaryMediaTypes-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBinaryMediaTypes() {
        return binaryMediaTypes;
    }

    /**
     * Legt den Wert der binaryMediaTypes-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBinaryMediaTypes(String value) {
        this.binaryMediaTypes = value;
    }

    /**
     * Ruft den Wert der errorHandler-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorHandler() {
        return errorHandler;
    }

    /**
     * Legt den Wert der errorHandler-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorHandler(String value) {
        this.errorHandler = value;
    }

    /**
     * Ruft den Wert der errorStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorStrategy() {
        return errorStrategy;
    }

    /**
     * Legt den Wert der errorStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorStrategy(String value) {
        this.errorStrategy = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}

==> citrus-http-4.1.1-sources.jar: org/citrusframework/model/config/http/HttpClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.http;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="request-url" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="request-method" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-resolver" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="request-factory" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="rest-template" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="content-type" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="default-accept-header" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="handle-cookies" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="binary-media-types" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="error-handler" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="error-strategy">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             <enumeration value="throwsException"/>
 *             <enumeration value="propagateError"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class HttpClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "request-url")
    protected String requestUrl;
    @XmlAttribute(name = "request-method")
    protected String requestMethod;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "endpoint-resolver")
    protected String endpointResolver;
    @XmlAttribute(name = "request-factory")
    protected String requestFactory;
    @XmlAttribute(name = "rest-template")
    protected String restTemplate;
    @XmlAttribute(name = "charset")
    protected String charset;
    @XmlAttribute(name = "content-type")
    protected String contentType;
    @XmlAttribute(name = "default-accept-header")
    protected Boolean defaultAcceptHeader;
    @XmlAttribute(name = "handle-cookies")
    protected Boolean handleCookies;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "binary-media-types")
    protected String binaryMediaTypes;
    @XmlAttribute(name = "error-handler")
    protected String errorHandler;
    @XmlAttribute(name = "error-strategy")
    protected String errorStrategy;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der requestUrl-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestUrl() {
        return requestUrl;
    }

    /**
     * Legt den Wert der requestUrl-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestUrl(String value) {
        this.requestUrl = value;
    }

    /**
     * Ruft den Wert der requestMethod-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestMethod() {
        return requestMethod;
    }

    /**
     * Legt den Wert der requestMethod-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestMethod(String value) {
        this.requestMethod = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der endpointResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointResolver() {
        return endpointResolver;
    }

    /**
     * Legt den Wert der endpointResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointResolver(String value) {
        this.endpointResolver = value;
    }

    /**
     * Ruft den Wert der requestFactory-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestFactory() {
        return requestFactory;
    }

    /**
     * Legt den Wert der requestFactory-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestFactory(String value) {
        this.requestFactory = value;
    }

    /**
     * Ruft den Wert der restTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRestTemplate() {
        return restTemplate;
    }

    /**
     * Legt den Wert der restTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRestTemplate(String value) {
        this.restTemplate = value;
    }

    /**
     * Ruft den Wert der charset-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCharset() {
        return charset;
    }

    /**
     * Legt den Wert der charset-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCharset(String value) {
        this.charset = value;
    }

    /**
     * Ruft den Wert der contentType-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Legt den Wert der contentType-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContentType(String value) {
        this.contentType = value;
    }

    /**
     * Ruft den Wert der defaultAcceptHeader-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDefaultAcceptHeader() {
        return defaultAcceptHeader;
    }

    /**
     * Legt den Wert der defaultAcceptHeader-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDefaultAcceptHeader(Boolean value) {
        this.defaultAcceptHeader = value;
    }

    /**
     * Ruft den Wert der handleCookies-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isHandleCookies() {
        return handleCookies;
    }

    /**
     * Legt den Wert der handleCookies-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setHandleCookies(Boolean value) {
        this.handleCookies = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der binaryMediaTypes-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBinaryMediaTypes() {
        return binaryMediaTypes;
    }

    /**
     * Legt den Wert der binaryMediaTypes-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBinaryMediaTypes(String value) {
        this.binaryMediaTypes = value;
    }

    /**
     * Ruft den Wert der errorHandler-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorHandler() {
        return errorHandler;
    }

    /**
     * Legt den Wert der errorHandler-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorHandler(String value) {
        this.errorHandler = value;
    }

    /**
     * Ruft den Wert der errorStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorStrategy() {
        return errorStrategy;
    }

    /**
     * Legt den Wert der errorStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorStrategy(String value) {
        this.errorStrategy = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}
